/*
 * Copyright 2009 Ben Axelrod
 * 
 * This program is free software: you can redistribute it and/or modify it
 * under the terms of the Creative Commons Attribution-Noncommercial-Share
 * Alike 3.0 United States License. 
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * 
 * To view a copy of this license, visit:
 * 
 * http://creativecommons.org/licenses/by-nc-sa/3.0/us/
 *
 * or send a letter to:
 * Creative Commons
 * 171 Second Street, Suite 300
 * San Francisco, California 94105 USA
 */


using Microsoft.Ccr.Core;
using Microsoft.Dss.Core.Attributes;
using Microsoft.Dss.ServiceModel.Dssp;
using System;
using System.Collections.Generic;
using W3C.Soap;

// for Http Operations
using System.Net;
using System.Collections.Specialized;
using Microsoft.Dss.Core.DsspHttp;
using Microsoft.Dss.Core.DsspHttpUtilities;
using System.Drawing;

namespace Robotics.Mapper
{

    /// <summary>
    /// Mapper Contract
    /// </summary>
    public sealed class Contract
    {
        /// The Unique Contract Identifier for the Mapper service
        public const String Identifier = "http://schemas.roboben.com/2007/01/mapper.html";
    }

    /// <summary>
    /// Mapper State
    /// </summary>
    [DataContract()]
    public class MapperState
    {
        [DataMember]
        public float LatestX;

        [DataMember]
        public float LatestZ;

        [DataMember]
        public float LatestAngle;

        [DataMember]
        public int[] LatestDistanceMeasurements;

        [DataMember]
        public List<PointList> AllDistanceMeasurements;
    }

    [DataContract]
    public class PointList
    {
        [DataMember]
        public List<Point> Points;

        public PointList() { }
        public PointList(List<Point> p)
        {
            this.Points = p;
        }
    }

    /// <summary>
    /// Mapper Operations
    /// </summary>
    public class MapperOperations : PortSet<
        DsspDefaultLookup, 
        DsspDefaultDrop, 
        Get, 
        Replace, 
        HttpGet>
    {
    }

    /// <summary>
    /// Get the state value
    /// </summary>
    public class Get : Get<GetRequestType, PortSet<MapperState, Fault>>
    {
    }

    /// <summary>
    /// Replace the state value
    /// </summary>
    public class Replace : Replace<MapperState, PortSet<DefaultReplaceResponseType, Fault>>
    {
    }


}
