/*
 * Copyright 2009 Ben Axelrod
 * 
 * This program is free software: you can redistribute it and/or modify it
 * under the terms of the Creative Commons Attribution-Noncommercial-Share
 * Alike 3.0 United States License. 
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * 
 * To view a copy of this license, visit:
 * 
 * http://creativecommons.org/licenses/by-nc-sa/3.0/us/
 *
 * or send a letter to:
 * Creative Commons
 * 171 Second Street, Suite 300
 * San Francisco, California 94105 USA
 */

//------------------------------------------------------------------------------
// BehaviorVote.cs
//
//     Generic contract for behavior based arbitration
//
// Ben Axelrod, Gaurav Gupta  -  2007
//
//------------------------------------------------------------------------------
using Microsoft.Ccr.Core;
using Microsoft.Dss.Core.Attributes;
using Microsoft.Dss.ServiceModel.Dssp;
using System;
using System.Collections.Generic;
using W3C.Soap;


namespace Microsoft.Robotics.Services.BehaviorVote
{
    /// <summary>
    /// BehaviorVote Contract
    /// </summary>
    public sealed class Contract
    {
        /// The Unique Contract Identifier for the SimplePosition service
        public const string Identifier = "http://schemas.microsoft.com/robotics/2007/04/behaviorvote.html";
    }

    /// <summary>
    /// A vote array for one behavior
    /// </summary>
    [DataContract]
    public class BehaviorVote
    {
        /// <summary>
        /// An array of size 720 (one vote per 0.5 degree)
        /// range +1 to -1.  negative votes are veto votes.
        /// </summary>
        [DataMember]
        public double[] Votes = new double[720];

        /// <summary>
        /// Time stamp of this vote
        /// </summary>
        [DataMember]
        public DateTime TimeStamp;
    }


}
