/*
 * Copyright 2009 Ben Axelrod
 * 
 * This program is free software: you can redistribute it and/or modify it
 * under the terms of the Creative Commons Attribution-Noncommercial-Share
 * Alike 3.0 United States License. 
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * 
 * To view a copy of this license, visit:
 * 
 * http://creativecommons.org/licenses/by-nc-sa/3.0/us/
 *
 * or send a letter to:
 * Creative Commons
 * 171 Second Street, Suite 300
 * San Francisco, California 94105 USA
 */

//------------------------------------------------------------------------------
// GenericParrallelGripper.cs
//
//     Generic Parrallel Gripper interface
//
// Ben Axelrod, John Hutchison  -  2007
//
//------------------------------------------------------------------------------

using Microsoft.Ccr.Core;
using Microsoft.Dss.Core.Attributes;
using Microsoft.Dss.ServiceModel.Dssp;
using System;
using System.Collections.Generic;
using W3C.Soap;

namespace Microsoft.Robotics.Services.GenericParrallelGripper
{
    /// <summary>
    /// GenericParrallelGripper Contract
    /// </summary>
    public sealed class Contract
    {
        public const string Identifier = "http://schemas.microsoft.com/robotics/2007/04/genericparrallelgripper.html";
    }

    /// <summary>
    /// GenericParrallelGripper State
    /// </summary>
    [DataContract]
    public class GenericParrallelGripperState
    {
        [DataMember]
        public float ActualVelocity;   //current velocity read-only from the gripper

        [DataMember]
        public float TargetVelocity;   //desired velocity write-only to gripper

        [DataMember]
        public float TargetPosition;   //goal position to be attained write-only to gripper

        [DataMember]
        public float ActualPosition;   //position read-only from the gripper

        [DataMember]
        public float MinPosition;  //minimum allowable distance between fingers

        [DataMember]
        public float MaxPosition;  //max allowable distance between fingers

        [DataMember]
        public int HardwareIdentifier;

        [DataMember]
        public string IDstring;
    }

    /// <summary>
    /// GenericParrallelGripper Operations
    /// </summary>
    [ServicePort]
    public class GenericParrallelGripperOperations : PortSet<
        DsspDefaultLookup,
        DsspDefaultDrop,
        Get,
        Replace,
        MoveFingersTo,
        ReliableSubscribe, //must come before Subscribe
        Subscribe>
    {
    }

    ///<summary>
    /// MoveFingersTo
    /// Used to set the distance between the fingers of a parrallel gripper
    ///</summary>
    public class MoveFingersTo : Update<PositionMessage, PortSet<DefaultUpdateResponseType, Fault>>
    {
    }

    [DataContract]
    public class PositionMessage
    {
        [DataMember]
        public float GoalPosition;
    }

    /// <summary>
    /// Get
    /// </summary>
    public class Get : Get<GetRequestType, PortSet<GenericParrallelGripperState, Fault>>
    {
    }

    /// <summary>
    /// Replace entire state
    /// </summary>
    public class Replace : Replace<GenericParrallelGripperState, PortSet<DefaultReplaceResponseType, Fault>>
    {
    }

    /// <summary>
    /// Subscribe
    /// </summary>
    public class Subscribe : Subscribe<SubscribeRequestType, PortSet<SubscribeResponseType, Fault>>
    {
    }

    /// <summary>
    /// Reliable Subscribe
    /// </summary>
    public class ReliableSubscribe : Subscribe<ReliableSubscribeRequestType, PortSet<SubscribeResponseType, Fault>>
    {
    }
}