/*
 * Copyright 2009 Ben Axelrod
 * 
 * This program is free software: you can redistribute it and/or modify it
 * under the terms of the Creative Commons Attribution-Noncommercial-Share
 * Alike 3.0 United States License. 
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * 
 * To view a copy of this license, visit:
 * 
 * http://creativecommons.org/licenses/by-nc-sa/3.0/us/
 *
 * or send a letter to:
 * Creative Commons
 * 171 Second Street, Suite 300
 * San Francisco, California 94105 USA
 */

//------------------------------------------------------------------------------
// SimplePosition.cs
//
//     Generic contract for simple 2D positioning devices
//
// Ben Axelrod  -  08/2007
// 
//------------------------------------------------------------------------------
using Microsoft.Ccr.Core;
using Microsoft.Dss.Core.Attributes;
using Microsoft.Dss.ServiceModel.Dssp;
using System;
using System.Collections.Generic;
using W3C.Soap;


namespace Microsoft.Robotics.Services.SimplePosition
{
    
    /// <summary>
    /// SimplePosition Contract
    /// </summary>
    public sealed class Contract
    {
        /// The Unique Contract Identifier for the SimplePosition service
        public const string Identifier = "http://schemas.microsoft.com/robotics/2007/04/simpleposition.html";
    }

    /// <summary>
    /// SimplePosition State
    /// </summary>
    [DataContract]
    public class SimplePositionState
    {
        /// <summary>
        /// Current X position estimate in meters
        /// </summary>
        [DataMember]
        public double X;

        /// <summary>
        /// Current Y position estimate in meters
        /// </summary>
        [DataMember]
        public double Y;

        /// <summary>
        /// Current angle estimate in radians
        /// </summary>
        [DataMember]
        public double Theta;

        /// <summary>
        /// Time stamp of this estimate
        /// </summary>
        [DataMember]
        public DateTime TimeStamp;

    }

    /// <summary>
    /// SimplePosition Operations
    /// </summary>
    [ServicePort]
    public class SimplePositionOperations : PortSet<
        DsspDefaultLookup, 
        DsspDefaultDrop, 
        Get,
        Replace,
        ReliableSubscribe, //must come before Subscribe
        Subscribe>
    {
    }

    /// <summary>
    /// Get
    /// </summary>
    public class Get : Get<GetRequestType, PortSet<SimplePositionState, Fault>>
    {
    }

    /// <summary>
    /// Replace entire state
    /// </summary>
    public class Replace : Replace<SimplePositionState, PortSet<DefaultReplaceResponseType, Fault>>
    {
    }

    /// <summary>
    /// Subscribe
    /// </summary>
    public class Subscribe : Subscribe<SubscribeRequestType, PortSet<SubscribeResponseType, Fault>>
    {
    }

    /// <summary>
    /// Reliable Subscribe
    /// </summary>
    public class ReliableSubscribe : Subscribe<ReliableSubscribeRequestType, PortSet<SubscribeResponseType, Fault>>
    {
    }

}
