/*
 * Copyright 2009 Ben Axelrod
 * 
 * This program is free software: you can redistribute it and/or modify it
 * under the terms of the Creative Commons Attribution-Noncommercial-Share
 * Alike 3.0 United States License. 
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * 
 * To view a copy of this license, visit:
 * 
 * http://creativecommons.org/licenses/by-nc-sa/3.0/us/
 *
 * or send a letter to:
 * Creative Commons
 * 171 Second Street, Suite 300
 * San Francisco, California 94105 USA
 */

using Microsoft.Ccr.Core;
using Microsoft.Dss.Core.Attributes;
using Microsoft.Dss.ServiceModel.Dssp;
using System;
using System.Collections.Generic;
using W3C.Soap;
using simrobot = Robotics.SimRobot;
using Microsoft.Robotics.PhysicalModel;

using sicklrf = Microsoft.Robotics.Services.Sensors.SickLRF.Proxy;

namespace Robotics.SimRobot
{
    
    /// <summary>
    /// SimRobot Contract
    /// </summary>
    public sealed class Contract
    {
        /// The Unique Contract Identifier for the SimRobot service
        public const String Identifier = "http://schemas.tempuri.org/2007/01/simrobot.html";
    }
    /// <summary>
    /// Sim Robot State
    /// </summary>
    [DataContract()]
    public class SimRobotState
    {
        [DataMember]
        public Pose robotPose;

        [DataMember]
        public DateTime poseUpdated;
    }

    /// <summary>
    /// Sim Robot Operations
    /// </summary>
    public class SimRobotOperations : PortSet<
        DsspDefaultLookup, 
        DsspDefaultDrop, 
        Get,
        Replace,
        Subscribe>
    {
    }

    /// <summary>
    /// Get
    /// </summary>
    public class Get : Get<GetRequestType, PortSet<SimRobotState, Fault>>
    {
    }

    /// <summary>
    /// Replace
    /// </summary>
    public class Replace : Replace<SimRobotState, PortSet<DefaultReplaceResponseType, Fault>>
    {
        public Replace() { }

        public Replace(SimRobotState r)
        {
            this.Body = r;
        }
    }

    /// <summary>
    /// subscribe to the pose updates of SimRobot
    /// </summary>
    public class Subscribe : Subscribe<SubscribeRequestType, PortSet<SubscribeResponseType, Fault>>
    {
    }
}
